dialogs Package
===============

:mod:`dialogs` Package
----------------------

.. automodule:: stoqlib.gui.dialogs
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`addressdialog` Module
---------------------------

.. automodule:: stoqlib.gui.dialogs.addressdialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`batchselectiondialog` Module
-----------------------------

.. automodule:: stoqlib.gui.dialogs.batchselectiondialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`branchdialog` Module
--------------------------

.. automodule:: stoqlib.gui.dialogs.branchdialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`clientcategorydialog` Module
----------------------------------

.. automodule:: stoqlib.gui.dialogs.clientcategorydialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`clientdetails` Module
---------------------------

.. automodule:: stoqlib.gui.dialogs.clientdetails
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`credentialsdialog` Module
-------------------------------

.. automodule:: stoqlib.gui.dialogs.credentialsdialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`contactsdialog` Module
----------------------------

.. automodule:: stoqlib.gui.dialogs.contactsdialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`costcenterdialog` Module
------------------------------

.. automodule:: stoqlib.gui.dialogs.costcenterdialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`crashreportdialog` Module
-------------------------------

.. automodule:: stoqlib.gui.dialogs.crashreportdialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`creditdialog` Module
-------------------------------

.. automodule:: stoqlib.gui.dialogs.creditdialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`daterangedialog` Module
-----------------------------

.. automodule:: stoqlib.gui.dialogs.daterangedialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`devices` Module
---------------------

.. automodule:: stoqlib.gui.dialogs.devices
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`financialreportdialog` Module
-----------------------------------

.. automodule:: stoqlib.gui.dialogs.financialreportdialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`feedbackdialog` Module
----------------------------

.. automodule:: stoqlib.gui.dialogs.feedbackdialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`importerdialog` Module
----------------------------

.. automodule:: stoqlib.gui.dialogs.importerdialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`initialstockdialog` Module
--------------------------------

.. automodule:: stoqlib.gui.dialogs.initialstockdialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`invoicedialog` Module
---------------------------

.. automodule:: stoqlib.gui.dialogs.invoicedialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`inventorydetails` Module
------------------------------

.. automodule:: stoqlib.gui.dialogs.inventorydetails
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`labeldialog` Module
-------------------------

.. automodule:: stoqlib.gui.dialogs.labeldialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`loandetails` Module
-------------------------

.. automodule:: stoqlib.gui.dialogs.loandetails
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`manufacturerdialog` Module
--------------------------------

.. automodule:: stoqlib.gui.dialogs.manufacturerdialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`missingitemsdialog` Module
--------------------------------

.. automodule:: stoqlib.gui.dialogs.missingitemsdialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`paymentcategorydialog` Module
-----------------------------------

.. automodule:: stoqlib.gui.dialogs.paymentcategorydialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`paymentchangedialog` Module
---------------------------------

.. automodule:: stoqlib.gui.dialogs.paymentchangedialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`paymentcommentsdialog` Module
-----------------------------------

.. automodule:: stoqlib.gui.dialogs.paymentcommentsdialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`paymentdetails` Module
----------------------------

.. automodule:: stoqlib.gui.dialogs.paymentdetails
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`paymentflowhistorydialog` Module
--------------------------------------

.. automodule:: stoqlib.gui.dialogs.paymentflowhistorydialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`paymentmethod` Module
---------------------------

.. automodule:: stoqlib.gui.dialogs.paymentmethod
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`pluginsdialog` Module
---------------------------

.. automodule:: stoqlib.gui.dialogs.pluginsdialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`productiondetails` Module
-------------------------------

.. automodule:: stoqlib.gui.dialogs.productiondetails
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`productionquotedialog` Module
-----------------------------------

.. automodule:: stoqlib.gui.dialogs.productionquotedialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`productstockdetails` Module
---------------------------------

.. automodule:: stoqlib.gui.dialogs.productstockdetails
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`progressdialog` Module
----------------------------

.. automodule:: stoqlib.gui.dialogs.progressdialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`progressbardialog` Module
-------------------------------

.. automodule:: stoqlib.gui.dialogs.progressbardialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`purchasedetails` Module
-----------------------------

.. automodule:: stoqlib.gui.dialogs.purchasedetails
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`quotedialog` Module
-------------------------

.. automodule:: stoqlib.gui.dialogs.quotedialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`receivingdialog` Module
-----------------------------

.. automodule:: stoqlib.gui.dialogs.receivingdialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`renegotiationdetails` Module
----------------------------------

.. automodule:: stoqlib.gui.dialogs.renegotiationdetails
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`saledetails` Module
-------------------------

.. automodule:: stoqlib.gui.dialogs.saledetails
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sellabledialog` Module
----------------------------

.. automodule:: stoqlib.gui.dialogs.sellabledialog
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`sellableimage` Module
---------------------------

.. automodule:: stoqlib.gui.dialogs.sellableimage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sellablepricedialog` Module
---------------------------------

.. automodule:: stoqlib.gui.dialogs.sellablepricedialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sintegradialog` Module
----------------------------

.. automodule:: stoqlib.gui.dialogs.sintegradialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`spreadsheetexporterdialog` Module
---------------------------------------

.. automodule:: stoqlib.gui.dialogs.spreadsheetexporterdialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`startproduction` Module
-----------------------------

.. automodule:: stoqlib.gui.dialogs.startproduction
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`stockcostdialog` Module
-----------------------------

.. automodule:: stoqlib.gui.dialogs.stockcostdialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`stockdecreasedialog` Module
---------------------------------

.. automodule:: stoqlib.gui.dialogs.stockdecreasedialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`supplierdetails` Module
-----------------------------

.. automodule:: stoqlib.gui.dialogs.supplierdetails
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`tillhistory` Module
-------------------------

.. automodule:: stoqlib.gui.dialogs.tillhistory
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`transferorderdialog` Module
---------------------------------

.. automodule:: stoqlib.gui.dialogs.transferorderdialog
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`workordercategorydialog` Module
-------------------------------------

.. automodule:: stoqlib.gui.dialogs.workordercategorydialog
    :members:
    :undoc-members:
    :show-inheritance:
